<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\UserGameStats;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Carbon\Carbon;

class UserGameStatsController extends Controller
{
    public function saveGameStats(Request $request)
    {
        // ✅ Validate incoming data
        $validated = $request->validate([
            'game_name' => 'required|string',
            'games_played' => 'required|integer|min:0',
            'games_won' => 'required|integer|min:0',
            'best_try' => 'required|integer|min:0',
            'current_streak' => 'required|integer|min:0',
            'max_streak' => 'required|integer|min:0',
            'last_played_at' => 'nullable|date',
            'level' => 'required|integer|min:1',
        ]);

        // ✅ Get the authenticated user
        $user = Auth::user();

        if (!$user) {
            return response()->json([
                'status' => 'error',
                'message' => 'User not authenticated',
            ], 401);
        }

        // ✅ Update or create user game stats
        $gameStats = UserGameStats::updateOrCreate(
            ['user_id' => $user->id, 'game_name' => $validated['game_name']],
            [
                'games_played' => $validated['games_played'],
                'games_won' => $validated['games_won'],
                'best_try' => $validated['best_try'],
                'current_streak' => $validated['current_streak'],
                'max_streak' => $validated['max_streak'],
                'last_played_at' => $validated['last_played_at'] ? Carbon::parse($validated['last_played_at'])->format('Y-m-d') : null,
                'level' => $validated['level'],
            ]
        );

        // ✅ Update overall level (Weighted Average)
        $userGames = UserGameStats::where('user_id', $user->id)->get();
        $totalGamesPlayed = $userGames->sum('games_played');
        $weightedLevelSum = $userGames->sum(function ($game) {
            return $game->level * $game->games_played;
        });

        if ($totalGamesPlayed > 0) {
            $user->overall_level = round($weightedLevelSum / $totalGamesPlayed);
            $user->save();
        }

        return response()->json([
            'status' => 'success',
            'message' => 'Game stats updated successfully',
            'user' => $user,
            'game_stats' => $gameStats,
        ], 200);
    }
}
