<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UserController;
use App\Http\Controllers\BannerController;
use App\Http\Controllers\UserGameStatsController;
use App\Http\Controllers\ChallengeController;

/*
|--------------------------------------------------------------------------
| Public Routes (No Authentication)
|--------------------------------------------------------------------------
*/
Route::post('/register', [UserController::class, 'register']); // User registration
Route::post('/login', [UserController::class, 'login']); // User login

/*
|--------------------------------------------------------------------------
| Protected Routes (Require Authentication)
|--------------------------------------------------------------------------
*/
Route::middleware('auth:sanctum')->group(function () {
    Route::post('/logout', [UserController::class, 'logout']); // Logout
    Route::post('/save/game/stats', [UserGameStatsController::class, 'saveGameStats']);

    Route::put('/users/{id}', [UserController::class, 'updateUser']); // Update user
    Route::delete('/users/{id}', [UserController::class, 'deleteUser']); // Delete user (Admin only)

    // Banners
    Route::get('/banners', [BannerController::class, 'getBanners']); // Get all banners
    Route::get('/banners/{id}', [BannerController::class, 'getBannerById']); // Get single banner
    Route::post('/banners', [BannerController::class, 'createBanner']); // Create a banner
    Route::put('/banners/{id}', [BannerController::class, 'updateBanner']); // Update a banner
    Route::delete('/banners/{id}', [BannerController::class, 'deleteBanner']); // Delete a banner


    Route::post('/challenges/create', [ChallengeController::class, 'createChallenge']);
    Route::get('/challenges/{code}', [ChallengeController::class, 'getChallenge']);
    Route::post('/challenges/update/status', [ChallengeController::class, 'updateChallengeStatus']);
    Route::post('/challenge/join', [ChallengeController::class, 'joinChallenge']);
    Route::post('/challenge/update/result', [ChallengeController::class, 'updateChallengeResult']);
});
